netapp_ontap.models.consistency_group_nvme_host_dh_hmac_chap API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.consistency_group_nvme_host_dh_hmac_chap`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ConsistencyGroupNvmeHostDhHmacChapSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ConsistencyGroupNvmeHostDhHmacChap object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `controller_secret_key: str POST`

    The controller secret for NVMe in-band authentication. The value of this property is used by the NVMe host to authenticate the NVMe controller while establishing a connection. If unset, the controller is not authenticated. When supplied, the property `host_secret_key` must also be supplied. Optional in POST.
    This property is write-only. The `mode` property can be used to identify if a controller secret has been set for the host, but the controller secret value cannot be read. To change the value, the host must be deleted from the subsystem and re-added.

    Example: DHHC-1:00:ia6zGodOr4SEG0Zzaw398rpY0wqipUWj4jWjUh4HWUz6aQ2n:

  `group_size: str GET POST`

    The Diffie-Hellman group size for NVMe in-band authentication. When property `host_secret_key` is provided, this property defaults to `2048_bit`. When supplied, the property `host_secret_key` must also be supplied. Optional in POST.

    Valid choices:

    - none
    - 2048_bit
    - 3072_bit
    - 4096_bit
    - 6144_bit
    - 8192_bit
  `hash_function: str GET POST`

    The hash function for NVMe in-band authentication. When property `host_secret_key` is provided, this property defaults to `sha_256`. When supplied, the property `host_secret_key` must also be supplied. Optional in POST.

    Valid choices:

    - sha_256
    - sha_512
  `host_secret_key: str POST`

    The host secret for NVMe in-band authentication. The value of this property is used by the NVMe controller to authenticate the NVMe host while establishing a connection. If unset, no authentication is performed by the host or controller. This property must be supplied if any other NVMe in-band authentication properties are supplied. Optional in POST.
    This property is write-only. The `mode` property can be used to identify if a host secret has been set for the host, but the host secret value cannot be read. To change the value, the host must be deleted from the subsystem and re-added.

    Example: DHHC-1:00:ia6zGodOr4SEG0Zzaw398rpY0wqipUWj4jWjUh4HWUz6aQ2n:

  `mode: str GET`

    The expected NVMe in-band authentication mode for the host. This property is an indication of which secrets are configured for the host. When set to: - none: The host has neither the host nor controller secret configured, and no authentication is performed. - unidirectional: The host has a host secret configured. The controller will authenticate the host. - bidirectional: The host has both a host and controller secret configured. The controller will authenticate the host and the host will authenticate the controller.

    Valid choices:

    - none
    - unidirectional
    - bidirectional